@@ -5,17 +5,16 @@ import logging
 
 try:
     # Python 3
-    from urllib.parse import urlencode, urlparse
+    from urllib.parse import urlencode
     from urllib.error import HTTPError
     from urllib.request import urlopen
 except ImportError:
     # Python 2
-    from urlparse import urlparse
     from urllib import urlencode, urlopen
     from urllib2 import HTTPError
 
 
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 VERSION = __version__
 
 API_URL = 'https://blimp-previews.herokuapp.com'
@@ -36,20 +35,19 @@ class FilePreviews(object):
         logger.debug('Initializing FilePreviews')
 
     def generate(self, url, **kwargs):
-        request_url = self._generate_request_url(url, **kwargs)
-
         logger.debug('Generating preview for {}'.format(url))
 
-        try:
-            urlopen(request_url)
-        except HTTPError:
-            pass
+        request_url = self._generate_request_url(url, **kwargs)
 
-        metadata = self._poll_for_metadata(url, **kwargs)
+        try:
+            response = urlopen(request_url)
+            preview_url = response.geturl()
+        except HTTPError as response:
+            preview_url = response.geturl()
 
         return {
-            'metadata': metadata,
-            'preview_url': self._generate_preview_url(url, **kwargs)
+            'metadata': self._poll_for_metadata(url, **kwargs),
+            'preview_url': preview_url
         }
 
     def _generate_request_url(self, url, **kwargs):
@@ -63,7 +61,17 @@ class FilePreviews(object):
             params['metadata'] = ','.join(metadata)
 
         if size:
-            params['size'] = self._dimensions_to_geometry(**size)
+            width = size.get('width')
+            height = size.get('height')
+            geometry = ''
+
+            if width:
+                geometry = width
+
+            if height:
+                geometry = '{}x{}'.format(geometry, height)
+
+            params['size'] = geometry
 
         return '{}/?{}'.format(self.api_url, urlencode(params))
 
@@ -75,21 +83,6 @@ class FilePreviews(object):
         url_hash = self._generate_url_hash(url, **kwargs)
         return '{}/{}/metadata.json'.format(self.results_url, url_hash)
 
-    def _generate_preview_url(self, url, **kwargs):
-        size = kwargs.get('size')
-        parsed_url = urlparse(url)
-        base_name = os.path.splitext(os.path.basename(parsed_url.path))[0]
-        url_hash = self._generate_url_hash(url, **kwargs)
-
-        if size:
-            geometry = self._dimensions_to_geometry(**size)
-            filename = '{}_{}_1.png'.format(base_name, geometry)
-        else:
-            filename = '{}_original_1.png'.format(base_name)
-
-        return '{}/{}/{}'.format(
-            self.results_url, url_hash, filename)
-
     def _poll_for_metadata(self, url, **kwargs):
         metadata_url = self._generate_metadata_url(url, **kwargs)
 
@@ -101,16 +94,3 @@ class FilePreviews(object):
             return json.loads(data.decode('utf-8'))
         except HTTPError:
             return self._poll_for_metadata(url, **kwargs)
-
-    def _dimensions_to_geometry(self, **size):
-        width = size.get('width')
-        height = size.get('height')
-        geometry = ''
-
-        if width:
-            geometry = width
-
-        if height:
-            geometry = '{}x{}'.format(geometry, height)
-
-        return geometry
